@@ -89,6 +89,7 @@ STRUCTURE = Nav(
                 Nav("Aminatou, the Fateshifter", cat="controle"),
                 Nav("Azusa, Lost but Seeking", cat="controle"),
                 Nav("Bjorna-Wernog", cat="controle", crop=True),
+                Nav("Cecily-Wernog", cat="combo", crop=True),
                 Nav("Dennick, Pious Apprentice", cat="midrange"),
                 Nav("Doran, the Siege Tower", cat="midrange"),
                 Nav("Dragonlord Ojutai", cat="controle"),
@@ -97,6 +98,7 @@ STRUCTURE = Nav(
                 Nav("Elminster", cat="controle"),
                 Nav("Erinis, Gloom Stalker", cat="midrange", crop=True),
                 Nav("Esika, God of the Tree", cat="controle"),
+                Nav("Ghyrson Starn, Kelermorph", cat="agro"),
                 Nav("Grenzo, Dungeon Warden", cat="combo"),
                 Nav("Grist, the Hunger Tide", cat="midrange"),
                 Nav("Gut, True Soul Zealot", cat="agro", crop=True),
@@ -111,6 +113,7 @@ STRUCTURE = Nav(
                 Nav("Killian, Ink Duelist", cat="agro"),
                 Nav("Kinnan, Bonder Prodigy", cat="combo"),
                 Nav("Klothys, God of Destiny", cat="controle"),
+                Nav("Kroxa, Titan of Death's Hunger", cat="midrange"),
                 Nav("Light-Paws, Emperor's Voice", cat="combo"),
                 Nav("Livio-Malcolm", cat="midrange", crop=True),
                 Nav("Livio-Prava", cat="agro", crop=True),
@@ -178,6 +181,8 @@ STRUCTURE = Nav(
                 Nav("32. Grenzo vs Shanna", cat="match"),
                 Nav("33. Juri vs Wilson", cat="match"),
                 Nav("34. Grist vs Raffine", cat="match"),
+                Nav("35. Cecily-Wernog vs Kroxa", cat="match"),
+                Nav("36. Ghyrson vs Niv-Mizzet", cat="match"),
             ],
         ),
         Nav(
